[![FactSet](https://raw.githubusercontent.com/factset/enterprise-sdk/main/docs/images/factset-logo.svg)](https://www.factset.com)

# ETF Profile and Prices client library for Python

[![API Version](https://img.shields.io/badge/api-vv1-blue)]()
[![PyPi](https://img.shields.io/pypi/v/fds.sdk.ETFProfileandPrices)](https://pypi.org/project/fds.sdk.ETFProfileandPrices/)
[![Apache-2 license](https://img.shields.io/badge/license-Apache2-brightgreen.svg)](https://www.apache.org/licenses/LICENSE-2.0)

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v1
- SDK version: 0.10.14
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements

* Python >= 3.7

## Installation

### Poetry

```shell
poetry add fds.sdk.utils fds.sdk.ETFProfileandPrices==0.10.14
```

### pip

```shell
pip install fds.sdk.utils fds.sdk.ETFProfileandPrices==0.10.14
```

## Usage

1. [Generate authentication credentials](../../../../README.md#authentication).
2. Setup Python environment.
   1. Install and activate python 3.7+. If you're using [pyenv](https://github.com/pyenv/pyenv):

      ```sh
      pyenv install 3.9.7
      pyenv shell 3.9.7
      ```

   2. (optional) [Install poetry](https://python-poetry.org/docs/#installation).
3. [Install dependencies](#installation).
4. Run the following:

> [!IMPORTANT]
> The parameter variables defined below are just examples and may potentially contain non valid values. Please replace them with valid values.

### Example Code

```python
from fds.sdk.utils.authentication import ConfidentialClient

import fds.sdk.ETFProfileandPrices
from fds.sdk.ETFProfileandPrices.api import factset_api
from fds.sdk.ETFProfileandPrices.models import *
from dateutil.parser import parse as dateutil_parser
from pprint import pprint

# See configuration.py for a list of all supported configuration parameters.

# Examples for each supported authentication method are below,
# choose one that satisfies your use case.

# (Preferred) OAuth 2.0: FactSetOAuth2
# See https://github.com/FactSet/enterprise-sdk#oauth-20
# for information on how to create the app-config.json file
#
# The confidential client instance should be reused in production environments.
# See https://github.com/FactSet/enterprise-sdk-utils-python#authentication
# for more information on using the ConfidentialClient class
configuration = fds.sdk.ETFProfileandPrices.Configuration(
    fds_oauth_client=ConfidentialClient('/path/to/app-config.json')
)

# Basic authentication: FactSetApiKey
# See https://github.com/FactSet/enterprise-sdk#api-key
# for information how to create an API key
# configuration = fds.sdk.ETFProfileandPrices.Configuration(
#     username='USERNAME-SERIAL',
#     password='API-KEY'
# )

# Enter a context with an instance of the API client
with fds.sdk.ETFProfileandPrices.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = factset_api.FactsetApi(api_client)
    symbol = "symbol_example" # str | Market symbol of ETP defined by FactSet.
    attributes = [
        "_attributes_example",
    ] # [str] | Limit the attributes returned in the response to the specified set. (optional)
    pagination_offset = 0.0 # float | Non-negative number of entries to skip, or 0 (default). (optional) if omitted the server will use the default value of 0.0
    pagination_limit = 20.0 # float | Non-negative maximum number of entries to return. (optional) if omitted the server will use the default value of 20.0

    try:
        # This endpoint returns selected ETP's asset allocations.
        # example passing only required values which don't have defaults set
        # and optional values
        api_response = api_instance.get_factset_etf_allocation_asset_list_by_symbol(symbol, attributes=attributes, pagination_offset=pagination_offset, pagination_limit=pagination_limit)

        pprint(api_response)
    except fds.sdk.ETFProfileandPrices.ApiException as e:
        print("Exception when calling FactsetApi->get_factset_etf_allocation_asset_list_by_symbol: %s\n" % e)

    # # Get response, http status code and response headers
    # try:
    #     # This endpoint returns selected ETP's asset allocations.
    #     api_response, http_status_code, response_headers = api_instance.get_factset_etf_allocation_asset_list_by_symbol_with_http_info(symbol, attributes=attributes, pagination_offset=pagination_offset, pagination_limit=pagination_limit)


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.ETFProfileandPrices.ApiException as e:
    #     print("Exception when calling FactsetApi->get_factset_etf_allocation_asset_list_by_symbol: %s\n" % e)

    # # Get response asynchronous
    # try:
    #     # This endpoint returns selected ETP's asset allocations.
    #     async_result = api_instance.get_factset_etf_allocation_asset_list_by_symbol_async(symbol, attributes=attributes, pagination_offset=pagination_offset, pagination_limit=pagination_limit)
    #     api_response = async_result.get()


    #     pprint(api_response)
    # except fds.sdk.ETFProfileandPrices.ApiException as e:
    #     print("Exception when calling FactsetApi->get_factset_etf_allocation_asset_list_by_symbol: %s\n" % e)

    # # Get response, http status code and response headers asynchronous
    # try:
    #     # This endpoint returns selected ETP's asset allocations.
    #     async_result = api_instance.get_factset_etf_allocation_asset_list_by_symbol_with_http_info_async(symbol, attributes=attributes, pagination_offset=pagination_offset, pagination_limit=pagination_limit)
    #     api_response, http_status_code, response_headers = async_result.get()


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.ETFProfileandPrices.ApiException as e:
    #     print("Exception when calling FactsetApi->get_factset_etf_allocation_asset_list_by_symbol: %s\n" % e)

```

### Using Pandas

To convert an API response to a Pandas DataFrame, it is necessary to transform it first to a dictionary.
```python
import pandas as pd

response_dict = api_response.to_dict()['data']

simple_json_response = pd.DataFrame(response_dict)
nested_json_response = pd.json_normalize(response_dict)
```

### Debugging

The SDK uses the standard library [`logging`](https://docs.python.org/3/library/logging.html#module-logging) module.

Setting `debug` to `True` on an instance of the `Configuration` class sets the log-level of related packages to `DEBUG`
and enables additional logging in Pythons [HTTP Client](https://docs.python.org/3/library/http.client.html).

**Note**: This prints out sensitive information (e.g. the full request and response). Use with care.

```python
import logging
import fds.sdk.ETFProfileandPrices

logging.basicConfig(level=logging.DEBUG)

configuration = fds.sdk.ETFProfileandPrices.Configuration(...)
configuration.debug = True
```

### Configure a Proxy

You can pass proxy settings to the Configuration class:

* `proxy`: The URL of the proxy to use.
* `proxy_headers`: a dictionary to pass additional headers to the proxy (e.g. `Proxy-Authorization`).

```python
import fds.sdk.ETFProfileandPrices

configuration = fds.sdk.ETFProfileandPrices.Configuration(
    # ...
    proxy="http://secret:password@localhost:5050",
    proxy_headers={
        "Custom-Proxy-Header": "Custom-Proxy-Header-Value"
    }
)
```

### Custom SSL Certificate

TLS/SSL certificate verification can be configured with the following Configuration parameters:

* `ssl_ca_cert`: a path to the certificate to use for verification in `PEM` format.
* `verify_ssl`: setting this to `False` disables the verification of certificates.
  Disabling the verification is not recommended, but it might be useful during
  local development or testing.

```python
import fds.sdk.ETFProfileandPrices

configuration = fds.sdk.ETFProfileandPrices.Configuration(
    # ...
    ssl_ca_cert='/path/to/ca.pem'
)
```

### Request Retries

In case the request retry behaviour should be customized, it is possible to pass a `urllib3.Retry` object to the `retry` property of the Configuration.

```python
from urllib3 import Retry
import fds.sdk.ETFProfileandPrices

configuration = fds.sdk.ETFProfileandPrices.Configuration(
    # ...
)

configuration.retries = Retry(total=3, status_forcelist=[500, 502, 503, 504])
```


## Documentation for API Endpoints

All URIs are relative to *https://api.factset.com/wealth/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*FactsetApi* | [**get_factset_etf_allocation_asset_list_by_symbol**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/FactsetApi.md#get_factset_etf_allocation_asset_list_by_symbol) | **GET** /factset/etf/allocation/asset/listBySymbol | This endpoint returns selected ETP&#39;s asset allocations.
*FactsetApi* | [**get_factset_etf_allocation_country_list_by_symbol**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/FactsetApi.md#get_factset_etf_allocation_country_list_by_symbol) | **GET** /factset/etf/allocation/country/listBySymbol | This endpoint returns selected ETP&#39;s country allocations.
*FactsetApi* | [**get_factset_etf_allocation_currency_list_by_symbol**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/FactsetApi.md#get_factset_etf_allocation_currency_list_by_symbol) | **GET** /factset/etf/allocation/currency/listBySymbol | This endpoint returns selected ETP&#39;s currency allocations.
*FactsetApi* | [**get_factset_etf_allocation_economic_development_list_by_symbol**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/FactsetApi.md#get_factset_etf_allocation_economic_development_list_by_symbol) | **GET** /factset/etf/allocation/economicDevelopment/listBySymbol | List of allocations classified by a holding&#39;s economic development status.
*FactsetApi* | [**get_factset_etf_allocation_exchange_list_by_symbol**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/FactsetApi.md#get_factset_etf_allocation_exchange_list_by_symbol) | **GET** /factset/etf/allocation/exchange/listBySymbol | This endpoint returns selected ETP&#39;s exchange allocations.
*FactsetApi* | [**get_factset_etf_allocation_industry_list_by_symbol**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/FactsetApi.md#get_factset_etf_allocation_industry_list_by_symbol) | **GET** /factset/etf/allocation/industry/listBySymbol | This endpoint returns selected ETP&#39;s industry allocations.
*FactsetApi* | [**get_factset_etf_allocation_market_capitalization_list_by_symbol**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/FactsetApi.md#get_factset_etf_allocation_market_capitalization_list_by_symbol) | **GET** /factset/etf/allocation/marketCapitalization/listBySymbol | List of allocations classified by a holding&#39;s total market capitalization.
*FactsetApi* | [**get_factset_etf_allocation_region_list_by_symbol**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/FactsetApi.md#get_factset_etf_allocation_region_list_by_symbol) | **GET** /factset/etf/allocation/region/listBySymbol | This endpoint returns selected ETP&#39;s region allocations.
*FactsetApi* | [**get_factset_etf_allocation_sector_list_by_symbol**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/FactsetApi.md#get_factset_etf_allocation_sector_list_by_symbol) | **GET** /factset/etf/allocation/sector/listBySymbol | This endpoint returns selected ETP&#39;s sector allocations.
*FactsetApi* | [**get_factset_etf_analytics_get_by_symbol**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/FactsetApi.md#get_factset_etf_analytics_get_by_symbol) | **GET** /factset/etf/analytics/getBySymbol | FactSet proprietary analytics datapoints for ETPs.
*FactsetApi* | [**get_factset_etf_analytics_holdings_statistics_get_by_symbol**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/FactsetApi.md#get_factset_etf_analytics_holdings_statistics_get_by_symbol) | **GET** /factset/etf/analytics/holdings/statistics/getBySymbol | FactSet&#39;s portfolio statistics for ETPs.
*FactsetApi* | [**get_factset_etf_analytics_score_get_by_symbol**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/FactsetApi.md#get_factset_etf_analytics_score_get_by_symbol) | **GET** /factset/etf/analytics/score/getBySymbol | FactSet proprietary ETP rankings.
*FactsetApi* | [**get_factset_etf_analytics_trade_get_by_symbol**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/FactsetApi.md#get_factset_etf_analytics_trade_get_by_symbol) | **GET** /factset/etf/analytics/trade/getBySymbol | Trade statistics for specific ETP.
*FactsetApi* | [**get_factset_etf_characteristics_get_by_symbol**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/FactsetApi.md#get_factset_etf_characteristics_get_by_symbol) | **GET** /factset/etf/characteristics/getBySymbol | Retrieve basic characteristic information for a specified ETP.
*FactsetApi* | [**get_factset_etf_class_category_broad_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/FactsetApi.md#get_factset_etf_class_category_broad_list) | **GET** /factset/etf/class/category/broad/list | List of ETP class broad categories.
*FactsetApi* | [**get_factset_etf_class_category_focus_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/FactsetApi.md#get_factset_etf_class_category_focus_list) | **GET** /factset/etf/class/category/focus/list | List of ETP class focus categories.
*FactsetApi* | [**get_factset_etf_class_category_niche_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/FactsetApi.md#get_factset_etf_class_category_niche_list) | **GET** /factset/etf/class/category/niche/list | List of ETP class niche categories.
*FactsetApi* | [**get_factset_etf_class_geography_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/FactsetApi.md#get_factset_etf_class_geography_list) | **GET** /factset/etf/class/geography/list | List of ETP class geographies.
*FactsetApi* | [**get_factset_etf_class_get_by_symbol**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/FactsetApi.md#get_factset_etf_class_get_by_symbol) | **GET** /factset/etf/class/getBySymbol | Retrieve an ETP&#39;s classification specific to asset class, geography, or investment strategy.
*FactsetApi* | [**get_factset_etf_competitors_list_by_symbol**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/FactsetApi.md#get_factset_etf_competitors_list_by_symbol) | **GET** /factset/etf/competitors/listBySymbol | FactSet&#39;s proprietary list of competing companies.
*FactsetApi* | [**get_factset_etf_distribution_get_by_symbol**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/FactsetApi.md#get_factset_etf_distribution_get_by_symbol) | **GET** /factset/etf/distribution/getBySymbol | Retrieve an ETP&#39;s current distribution details.
*FactsetApi* | [**get_factset_etf_fund_flows_get_by_symbol**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/FactsetApi.md#get_factset_etf_fund_flows_get_by_symbol) | **GET** /factset/etf/fundFlows/getBySymbol | Retrieve an ETP&#39;s cash inflow/outflows for various time periods.
*FactsetApi* | [**get_factset_etf_get_by_symbol**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/FactsetApi.md#get_factset_etf_get_by_symbol) | **GET** /factset/etf/getBySymbol | Retrieve basic profile information for a specified ETP.
*FactsetApi* | [**get_factset_etf_growth_of_ten_k_list_by_symbol**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/FactsetApi.md#get_factset_etf_growth_of_ten_k_list_by_symbol) | **GET** /factset/etf/growthOfTenK/listBySymbol | This endpoint returns selected ETP&#39;s Growth of 10K calculated values.
*FactsetApi* | [**get_factset_etf_holdings_list_by_symbol**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/FactsetApi.md#get_factset_etf_holdings_list_by_symbol) | **GET** /factset/etf/holdings/listBySymbol | Holdings details for an individual ETP.
*FactsetApi* | [**get_factset_etf_market_aggregates_get_by_symbol**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/FactsetApi.md#get_factset_etf_market_aggregates_get_by_symbol) | **GET** /factset/etf/marketAggregates/getBySymbol | Market aggregate data for ETPs.
*FactsetApi* | [**get_factset_etf_premium_discount_summary_list_by_symbol**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/FactsetApi.md#get_factset_etf_premium_discount_summary_list_by_symbol) | **GET** /factset/etf/premiumDiscount/summary/listBySymbol | Summary of ETP premium discount data.
*FactsetApi* | [**get_factset_etf_price_get_by_symbol**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/FactsetApi.md#get_factset_etf_price_get_by_symbol) | **GET** /factset/etf/price/getBySymbol | Retrieve historical ETP NAV values.
*FactsetApi* | [**get_factset_etf_returns_get_by_symbol**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/FactsetApi.md#get_factset_etf_returns_get_by_symbol) | **GET** /factset/etf/returns/getBySymbol | Retrieve total return data for a specified ETP.
*FactsetApi* | [**get_factset_etf_strategy_get_by_symbol**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/FactsetApi.md#get_factset_etf_strategy_get_by_symbol) | **GET** /factset/etf/strategy/getBySymbol | Retrieve various classification details for a specified ETP.
*FactsetApi* | [**get_factset_etf_strategy_segment_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/FactsetApi.md#get_factset_etf_strategy_segment_list) | **GET** /factset/etf/strategy/segment/list | Retrieve a list of ETP strategy segments.
*FactsetApi* | [**get_factset_etf_structure_get_by_symbol**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/FactsetApi.md#get_factset_etf_structure_get_by_symbol) | **GET** /factset/etf/structure/getBySymbol | Retrieve the basic structure information for a specified ETP.
*FactsetApi* | [**get_factset_etf_taxes_and_fees_us_get_by_symbol**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/FactsetApi.md#get_factset_etf_taxes_and_fees_us_get_by_symbol) | **GET** /factset/etf/taxesAndFees/us/getBySymbol | Retrieve the tax and fee related information for a specified ETP.
*FactsetApi* | [**get_factset_etf_time_series_list_by_symbol**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/FactsetApi.md#get_factset_etf_time_series_list_by_symbol) | **GET** /factset/etf/timeSeries/listBySymbol | Retrieve historical NAV data for a specified ETP.


## Documentation For Models

 - [AttributesMember](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/AttributesMember.md)
 - [CursorBasedPaginationOutputObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/CursorBasedPaginationOutputObject.md)
 - [CursorBasedPaginationOutputObjectWithoutTotal](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/CursorBasedPaginationOutputObjectWithoutTotal.md)
 - [ErrorMetaObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/ErrorMetaObject.md)
 - [ErrorObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/ErrorObject.md)
 - [InlineResponse200](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse200.md)
 - [InlineResponse2001](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse2001.md)
 - [InlineResponse20010](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20010.md)
 - [InlineResponse20010Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20010Data.md)
 - [InlineResponse20010DataIndexChange](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20010DataIndexChange.md)
 - [InlineResponse20010DataRisk](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20010DataRisk.md)
 - [InlineResponse20010DataSecurityLending](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20010DataSecurityLending.md)
 - [InlineResponse20011](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20011.md)
 - [InlineResponse20011Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20011Data.md)
 - [InlineResponse20012](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20012.md)
 - [InlineResponse20012Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20012Data.md)
 - [InlineResponse20012DataBeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20012DataBeta.md)
 - [InlineResponse20012DataEfficiency](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20012DataEfficiency.md)
 - [InlineResponse20012DataFit](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20012DataFit.md)
 - [InlineResponse20012DataTradability](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20012DataTradability.md)
 - [InlineResponse20013](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20013.md)
 - [InlineResponse20013Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20013Data.md)
 - [InlineResponse20013DataBlockTrade](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20013DataBlockTrade.md)
 - [InlineResponse20013DataImpedimentsToCreation](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20013DataImpedimentsToCreation.md)
 - [InlineResponse20013DataPremiumDiscount](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20013DataPremiumDiscount.md)
 - [InlineResponse20013DataSpread](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20013DataSpread.md)
 - [InlineResponse20013DataTrackingDifference](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20013DataTrackingDifference.md)
 - [InlineResponse20014](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20014.md)
 - [InlineResponse20014Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20014Data.md)
 - [InlineResponse20014DataCounterParty](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20014DataCounterParty.md)
 - [InlineResponse20014DataGearing](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20014DataGearing.md)
 - [InlineResponse20014DataGearingLeverage](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20014DataGearingLeverage.md)
 - [InlineResponse20014DataHedge](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20014DataHedge.md)
 - [InlineResponse20014DataServiceProvider](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20014DataServiceProvider.md)
 - [InlineResponse20015](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20015.md)
 - [InlineResponse20015Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20015Data.md)
 - [InlineResponse20015DataCategory](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20015DataCategory.md)
 - [InlineResponse20015DataGeography](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20015DataGeography.md)
 - [InlineResponse20016](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20016.md)
 - [InlineResponse20016Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20016Data.md)
 - [InlineResponse20017](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20017.md)
 - [InlineResponse20017Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20017Data.md)
 - [InlineResponse20018](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20018.md)
 - [InlineResponse20018Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20018Data.md)
 - [InlineResponse20019](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20019.md)
 - [InlineResponse20019Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20019Data.md)
 - [InlineResponse2001Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse2001Data.md)
 - [InlineResponse2001DataAssets](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse2001DataAssets.md)
 - [InlineResponse2001Meta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse2001Meta.md)
 - [InlineResponse2002](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse2002.md)
 - [InlineResponse20020](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20020.md)
 - [InlineResponse20020Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20020Data.md)
 - [InlineResponse20021](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20021.md)
 - [InlineResponse20021Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20021Data.md)
 - [InlineResponse20021DataCapitalGains](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20021DataCapitalGains.md)
 - [InlineResponse20021DataDividend](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20021DataDividend.md)
 - [InlineResponse20022](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20022.md)
 - [InlineResponse20022Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20022Data.md)
 - [InlineResponse20023](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20023.md)
 - [InlineResponse20023Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20023Data.md)
 - [InlineResponse20024](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20024.md)
 - [InlineResponse20024Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20024Data.md)
 - [InlineResponse20024Exchange](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20024Exchange.md)
 - [InlineResponse20025](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20025.md)
 - [InlineResponse20025Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20025Data.md)
 - [InlineResponse20025DataAverageLife](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20025DataAverageLife.md)
 - [InlineResponse20025DataOptionAdjustedSpread](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20025DataOptionAdjustedSpread.md)
 - [InlineResponse20026](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20026.md)
 - [InlineResponse20026Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20026Data.md)
 - [InlineResponse20026DataCount](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20026DataCount.md)
 - [InlineResponse20026DataSummary](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20026DataSummary.md)
 - [InlineResponse20027](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20027.md)
 - [InlineResponse20027Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20027Data.md)
 - [InlineResponse20027DataNav](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20027DataNav.md)
 - [InlineResponse20027DataNavLast](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20027DataNavLast.md)
 - [InlineResponse20027DataSharesOutstanding](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20027DataSharesOutstanding.md)
 - [InlineResponse20028](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20028.md)
 - [InlineResponse20028Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20028Data.md)
 - [InlineResponse20029](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20029.md)
 - [InlineResponse20029Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20029Data.md)
 - [InlineResponse2002Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse2002Data.md)
 - [InlineResponse2002DataCountries](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse2002DataCountries.md)
 - [InlineResponse2003](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse2003.md)
 - [InlineResponse20030](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20030.md)
 - [InlineResponse20030Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20030Data.md)
 - [InlineResponse20031](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20031.md)
 - [InlineResponse20031Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20031Data.md)
 - [InlineResponse20032](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20032.md)
 - [InlineResponse20032Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20032Data.md)
 - [InlineResponse20032DataExpenseRatio](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20032DataExpenseRatio.md)
 - [InlineResponse20032DataMaxCapitalGainsRate](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20032DataMaxCapitalGainsRate.md)
 - [InlineResponse20033](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20033.md)
 - [InlineResponse20033Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse20033Data.md)
 - [InlineResponse2003Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse2003Data.md)
 - [InlineResponse2003DataCurrencies](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse2003DataCurrencies.md)
 - [InlineResponse2004](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse2004.md)
 - [InlineResponse2004Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse2004Data.md)
 - [InlineResponse2004DataClassifications](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse2004DataClassifications.md)
 - [InlineResponse2005](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse2005.md)
 - [InlineResponse2005Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse2005Data.md)
 - [InlineResponse2005DataExchanges](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse2005DataExchanges.md)
 - [InlineResponse2006](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse2006.md)
 - [InlineResponse2006Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse2006Data.md)
 - [InlineResponse2006DataIndustries](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse2006DataIndustries.md)
 - [InlineResponse2007](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse2007.md)
 - [InlineResponse2007Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse2007Data.md)
 - [InlineResponse2007DataClassifications](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse2007DataClassifications.md)
 - [InlineResponse2008](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse2008.md)
 - [InlineResponse2008Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse2008Data.md)
 - [InlineResponse2008DataRegions](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse2008DataRegions.md)
 - [InlineResponse2009](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse2009.md)
 - [InlineResponse2009Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse2009Data.md)
 - [InlineResponse2009DataSectors](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse2009DataSectors.md)
 - [InlineResponse200Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse200Data.md)
 - [InlineResponse200DataBrand](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse200DataBrand.md)
 - [InlineResponse200DataCreateRedeem](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse200DataCreateRedeem.md)
 - [InlineResponse200DataCurrency](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse200DataCurrency.md)
 - [InlineResponse200DataDocumentation](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse200DataDocumentation.md)
 - [InlineResponse200DataExchange](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse200DataExchange.md)
 - [InlineResponse200DataFinancialReport](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse200DataFinancialReport.md)
 - [InlineResponse200DataFinancialReportAnnual](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse200DataFinancialReportAnnual.md)
 - [InlineResponse200DataFinancialReportSemiAnnual](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse200DataFinancialReportSemiAnnual.md)
 - [InlineResponse200DataIndex](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse200DataIndex.md)
 - [InlineResponse200DataInsight](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse200DataInsight.md)
 - [InlineResponse200DataIssuer](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse200DataIssuer.md)
 - [InlineResponse200DataTrading](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse200DataTrading.md)
 - [InlineResponse200DataTradingAverage](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse200DataTradingAverage.md)
 - [InlineResponse200DataTradingMedian](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse200DataTradingMedian.md)
 - [InlineResponse200Meta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/InlineResponse200Meta.md)
 - [LanguageMember](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/LanguageMember.md)
 - [OffsetBasedPaginationOutputObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/OffsetBasedPaginationOutputObject.md)
 - [OffsetBasedPaginationOutputObjectWithoutTotal](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/OffsetBasedPaginationOutputObjectWithoutTotal.md)
 - [PartialOutputObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/PartialOutputObject.md)
 - [StatusObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/ETFProfileandPrices/v2/docs/StatusObject.md)


## Documentation For Authorization


## FactSetApiKey

- **Type**: HTTP basic authentication


## FactSetOAuth2

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: N/A


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in fds.sdk.ETFProfileandPrices.apis and fds.sdk.ETFProfileandPrices.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from fds.sdk.ETFProfileandPrices.api.default_api import DefaultApi`
- `from fds.sdk.ETFProfileandPrices.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import fds.sdk.ETFProfileandPrices
from fds.sdk.ETFProfileandPrices.apis import *
from fds.sdk.ETFProfileandPrices.models import *
```

## Contributing

Please refer to the [contributing guide](../../../../CONTRIBUTING.md).

## Copyright

Copyright 2022 FactSet Research Systems Inc

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

